@@ -1,23 +1,15 @@
 use super::*;
 
-#[derive(Copy, Clone, PartialEq, PartialOrd, Eq, Ord)]
+#[derive(Clone)]
 pub struct NestedClass(pub Row);
 
 impl NestedClass {
     pub fn nested_type(&self) -> TypeDef {
-        TypeDef(Row::new(
-            self.0.u32(0) - 1,
-            TableIndex::TypeDef,
-            self.0.file,
-        ))
+        Row::new(self.0.u32(0) - 1, TableIndex::TypeDef, self.0.file).into()
     }
 
     pub fn enclosing_type(&self) -> TypeDef {
-        TypeDef(Row::new(
-            self.0.u32(1) - 1,
-            TableIndex::TypeDef,
-            self.0.file,
-        ))
+        Row::new(self.0.u32(1) - 1, TableIndex::TypeDef, self.0.file).into()
     }
 }
 
